@@ -13,7 +13,7 @@ try:
     import salt.config
     import salt.utils.files
     import salt.utils.dictupdate
-except ImportError:
+except ImportError:  # pragma: no cover
     # We need salt to test salt with saltfactories, and, when pytest is rewriting modules for proper assertion
     # reporting, we still haven't had a chance to inject the salt path into sys.modules, so we'll hit this
     # import error, but its safe to pass
