@@ -9,6 +9,8 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import contextlib
+import logging
 import os
 import socket
 import sys
@@ -24,6 +26,8 @@ except ImportError:  # pragma: no cover
 
 from saltfactories.utils import ports
 
+log = logging.getLogger(__name__)
+
 
 def skip_if_not_root():
     """
@@ -42,7 +46,7 @@ def skip_if_not_root():
                 return "You must be logged in as an Administrator to run this test"
 
 
-def skip_if_binaries_missing(binaries, check_all=False, message=None):
+def skip_if_binaries_missing(binaries, check_all=True, message=None):
     """
     Helper function to check for existing binaries
 
@@ -50,8 +54,10 @@ def skip_if_binaries_missing(binaries, check_all=False, message=None):
         binaries (list or tuple):
             Iterator of binaries to check
         check_all (bool):
-            Check all passed binaries. If ``True`` fails the check if at least
-            one binary is not found.
+            If ``check_all`` is ``True``, the default, all binaries must exist.
+            If ``check_all`` is ``False``, then only one the passed binaries needs to be found.
+            Usefull when, for example, passing a list of python interpreter names(python3.5,
+            python3, python), where only one needs to exist.
         message (str):
             Message to include in the skip reason.
 
@@ -63,14 +69,17 @@ def skip_if_binaries_missing(binaries, check_all=False, message=None):
         reason = "{} ".format(message)
     else:
         reason = ""
-    if check_all is True and salt.utils.path.which_bin(binaries) is None:
-        reason += "None of the following binaries was found: {}".format(", ".join(binaries))
-        return reason
-
-    for binary in binaries:
-        if salt.utils.path.which(binary) is None:
-            reason += "The '{}' binary was not found".format(binary)
+    if check_all is False:
+        # We only need one of the passed binaries to exist
+        if salt.utils.path.which_bin(binaries) is None:
+            reason += "None of the following binaries was found: {}".format(", ".join(binaries))
             return reason
+    else:
+        for binary in binaries:
+            if salt.utils.path.which(binary) is None:
+                reason += "The '{}' binary was not found".format(binary)
+                return reason
+    log.debug("All binaries found. Searched for: %s", ", ".join(binaries))
 
 
 def skip_if_no_local_network():
@@ -86,26 +95,22 @@ def skip_if_no_local_network():
     check_port_2 = ports.get_unused_localhost_port()
     has_local_network = False
     try:
-        pubsock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        retsock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        pubsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-        pubsock.bind(("", check_port_1))
-        pubsock.close()
-        retsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-        retsock.bind(("", check_port_2))
-        retsock.close()
+        with contextlib.closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as pubsock:
+            pubsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+            pubsock.bind(("", check_port_1))
+        with contextlib.closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as retsock:
+            retsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+            retsock.bind(("", check_port_2))
         has_local_network = True
     except socket.error:
         # I wonder if we just have IPV6 support?
         try:
-            pubsock = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
-            retsock = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
-            pubsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-            pubsock.bind(("", check_port_1))
-            pubsock.close()
-            retsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-            retsock.bind(("", check_port_2))
-            retsock.close()
+            with contextlib.closing(socket.socket(socket.AF_INET6, socket.SOCK_STREAM)) as pubsock:
+                pubsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+                pubsock.bind(("", check_port_1))
+            with contextlib.closing(socket.socket(socket.AF_INET6, socket.SOCK_STREAM)) as retsock:
+                retsock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+                retsock.bind(("", check_port_2))
             has_local_network = True
         except socket.error:
             # Let's continue
